@@ -1,5 +1,5 @@
 package overload::x;
-use 5.006; use strict; use warnings; our $VERSION = '0.10';
+use 5.006; use strict; use warnings; our $VERSION = '0.101';
 use base 'Import::Export';
 use Function::Fallback::CoreOrPP qw(clone);
 
@@ -12,7 +12,8 @@ use overload
 	'x' => \&x;
 
 sub n {
-	return bless \shift, __PACKAGE__;
+	my $n = shift; # \shift is really broken AND has varying behaviour depending on which OS you're using apparently
+	return bless \$n, __PACKAGE__;
 }
 
 sub x {
@@ -29,11 +30,11 @@ __END__
 
 =head1 NAME
 
-overload::x - x refs 
+overload::x - x on refs 
 
 =head1 VERSION
 
-Version 0.10
+Version 0.101
 
 =cut
 
